@@ -1,4 +1,4 @@
-/*	$Id: vilter-icap.c,v 1.32 2006/02/17 07:33:14 mbalmer Exp $	*/
+/*	$Id: vilter-icap.c,v 1.34 2006/06/06 13:13:22 mbalmer Exp $	*/
 
 /*
  * Copyright (c) 2004, 2005, 2006 Marc Balmer <marc@msys.ch>
@@ -57,7 +57,8 @@ int	 icap_tries;
 int	 icap_timeout;
 
 int
-vilter_scan(char *fn, size_t fnlen, char *chroot, char *virus, size_t namelen)
+vilter_scan(SMFICTX *ctx, char *fn, size_t fnlen, char *chroot, char *virus,
+    size_t namelen)
 {
 	int fd;
 	int try;
@@ -94,15 +95,19 @@ vilter_scan(char *fn, size_t fnlen, char *chroot, char *virus, size_t namelen)
 		if (inet_aton(bind_addr, &bind_sockaddr.sin_addr) == 0) {
 			hostent = gethostbyname(bind_addr);
 			if (!hostent) {
-				syslog(LOG_ERR, "icap: unknown bind address: %s", bind_addr);
+				syslog(LOG_ERR, "icap: unknown bind address: "
+				    "%s", bind_addr);
 				close(fd);
 				return SCAN_ERROR;
 			}
 			bind_sockaddr.sin_family = hostent->h_addrtype;
-			memcpy(&bind_sockaddr.sin_addr, hostent->h_addr, hostent->h_length);
+			memcpy(&bind_sockaddr.sin_addr, hostent->h_addr,
+			    hostent->h_length);
 		}
-		if (bind(fd, (struct sockaddr *)&bind_sockaddr, sizeof(bind_sockaddr))) {
-			syslog(LOG_ERR, "icap: can't bind to address %s", bind_addr);
+		if (bind(fd, (struct sockaddr *)&bind_sockaddr,
+		    sizeof(bind_sockaddr))) {
+			syslog(LOG_ERR, "icap: can't bind to address %s",
+			    bind_addr);
 			close(fd);
 			return SCAN_ERROR;
 		}
@@ -120,11 +125,13 @@ vilter_scan(char *fn, size_t fnlen, char *chroot, char *virus, size_t namelen)
 			return SCAN_ERROR;
 		}
 		server_sockaddr.sin_family = hostent->h_addrtype;
-		memcpy(&server_sockaddr.sin_addr, hostent->h_addr, hostent->h_length);
+		memcpy(&server_sockaddr.sin_addr, hostent->h_addr,
+		    hostent->h_length);
 	}
 	try = 0;
 
-	while (connect(fd, (struct sockaddr *)&server_sockaddr, sizeof(server_sockaddr)) == -1) {
+	while (connect(fd, (struct sockaddr *)&server_sockaddr,
+	    sizeof(server_sockaddr)) == -1) {
 		++try;
 
 		if (try == icap_tries) {
@@ -158,8 +165,9 @@ vilter_scan(char *fn, size_t fnlen, char *chroot, char *virus, size_t namelen)
 	    "User-Agent: smtp-vilter-%s/icap\r\n"
 	    "Allow: 204\r\n"
 	    "Encapsulated: req-hdr=0, res-hdr=%ld, res-body=%ld\r\n\r\n",
-	    icap_uri, icap_query != NULL ? "?" : "", icap_query != NULL ? icap_query : "",
-	    icap_host, icap_port, VERSION, (long)strlen(req_hdr), (long)(strlen(req_hdr) + strlen(res_hdr)));
+	    icap_uri, icap_query != NULL ? "?" : "", icap_query != NULL ?
+	    icap_query : "", icap_host, icap_port, VERSION,
+	    (long)strlen(req_hdr), (long)(strlen(req_hdr) + strlen(res_hdr)));
 
 	if (to_send(fd, buf, strlen(buf), 0, t) != strlen(buf)) {
 		syslog(LOG_ERR, "icap: send error");
@@ -190,21 +198,25 @@ vilter_scan(char *fn, size_t fnlen, char *chroot, char *virus, size_t namelen)
 		bzero(req_hdr, sizeof(req_hdr));
 		snprintf(req_hdr, sizeof(req_hdr), "%x\r\n", nread);
 
-		if (to_send(fd, req_hdr, strlen(req_hdr), 0, t) != strlen(req_hdr)) {
+		if (to_send(fd, req_hdr, strlen(req_hdr), 0, t) !=
+		    strlen(req_hdr)) {
 			syslog(LOG_ERR, "icap: chunksize send error");
 			goto response;
 		}
 
 		if ((nsent = to_send(fd, buf, nread, 0, t)) != nread) {
-			syslog(LOG_ERR, "icap: error sending chunk data of %d bytes (%d)", nread, nsent);
+			syslog(LOG_ERR, "icap: error sending chunk data of %d "
+			    "bytes (%d)", nread, nsent);
 			goto response;
 		}
 		bzero(buf, sizeof(buf));
 
 		snprintf(req_hdr, sizeof(req_hdr), "\r\n");
 
-		if (to_send(fd, req_hdr, strlen(req_hdr), 0, t) != strlen(req_hdr)) {
-			syslog(LOG_ERR, "icap: crlf send error %ld bytes", (long)strlen(req_hdr));
+		if (to_send(fd, req_hdr, strlen(req_hdr), 0, t) !=
+		    strlen(req_hdr)) {
+			syslog(LOG_ERR, "icap: crlf send error %ld bytes",
+			    (long)strlen(req_hdr));
 			goto response;
 		}
 	}
@@ -228,9 +240,11 @@ response:
 			result = SCAN_OK;
 		else if (!strncmp(buf, "ICAP/1.0 403", strlen("ICAP/1.0 403")))
 			result = SCAN_VIRUS;
-		else if (!strncmp(buf, "X-Violations-Found", strlen("X-Violations-Found")))
+		else if (!strncmp(buf, "X-Violations-Found",
+		    strlen("X-Violations-Found")))
 			result = SCAN_VIRUS;
-		else if (!strncmp(buf, "X-Infection-Found", strlen("X-Infection-Found"))) {
+		else if (!strncmp(buf, "X-Infection-Found",
+		    strlen("X-Infection-Found"))) {
 			if ((p = strstr(buf, "Threat=")) != NULL) {
 				p += strlen("Threat=");
 
