@@ -1,4 +1,4 @@
-/*	$Id: engine.c,v 1.63 2006/06/24 10:44:37 mbalmer Exp $	*/
+/*	$Id: engine.c,v 1.65 2006/11/12 11:38:08 mbalmer Exp $	*/
 
 /*
  * Copyright (c) 2003, 2004, 2005, 2006 Marc Balmer <marc@msys.ch>
@@ -313,12 +313,9 @@ message_cleanup(SMFICTX *ctx)
 		if (!keep_tmpfiles && unlink(msg->tfn))
 			syslog(LOG_ERR, "can't delete temp file %s", msg->tfn);
 
-		if (msg->msgid != NULL)
-			free(msg->msgid);
-		if (msg->envfrom != NULL)
-			free(msg->envfrom);
+		free(msg->msgid);
+		free(msg->envfrom);
 		/*
-		 * if (msg->envto != NULL)
 	 	 *	free(msg->envto);
 		 */
 		while (!SLIST_EMPTY(&msg->rhead)) {
@@ -326,8 +323,7 @@ message_cleanup(SMFICTX *ctx)
 
 			free(r->recipient);
 			free(r->mailLocalAddress);
-			if (r->spamprefix != NULL)
-				free(r->spamprefix);
+			free(r->spamprefix);
 
 			SLIST_REMOVE_HEAD(&msg->rhead, entries);
 			free(r);
@@ -336,18 +332,14 @@ message_cleanup(SMFICTX *ctx)
 		while (!SLIST_EMPTY(&msg->dhead)) {
 			d = SLIST_FIRST(&msg->dhead);
 			free(d->mailLocalDomain);
-			if (d->spamprefix != NULL)
-				free(d->spamprefix);
+			free(d->spamprefix);
 			SLIST_REMOVE_HEAD(&msg->dhead, entries);
 			free(d);
 		}
 
-		if (msg->hdrfrom != NULL)
-			free(msg->hdrfrom);
-		if (msg->hdrto != NULL)
-			free(msg->hdrto);
-		if (msg->subject != NULL)
-			free(msg->subject);
+		free(msg->hdrfrom);
+		free(msg->hdrto);
+		free(msg->subject);
 		free(msg);
 		priv->msg = NULL;
 	}
@@ -377,10 +369,8 @@ connection_cleanup(SMFICTX *ctx)
 		if (priv->conn != NULL) {
 			conn = priv->conn;
 
-			if (conn->hostname != NULL)
-				free(conn->hostname);
-			if (conn->heloname != NULL)
-				free(conn->heloname);
+			free(conn->hostname);
+			free(conn->heloname);
 			free(conn);
 		}
 
@@ -1376,8 +1366,7 @@ print_entries_with_values(LDAP *ld, LDAPMessage *result)
 			}
 			ldap_memfree(attr);
 		}
-		if (ber != NULL)
-			ber_free(ber, 0);
+		ber_free(ber, 0);
 	}
 }
 #endif
@@ -1794,7 +1783,13 @@ e_main(uid_t uid, gid_t gid, int pipe_m2e[2])
 	/* Initialize sendmail milter */
 	desc.xxfi_name = "smtp-vilter";
 	desc.xxfi_version = SMFI_VERSION;
-	desc.xxfi_flags = SMFIF_ADDHDRS | SMFIF_CHGHDRS | SMFIF_CHGBODY;
+	desc.xxfi_flags = SMFIF_ADDHDRS | SMFIF_CHGHDRS;
+
+	if ((virus_strategy == STRATEGY_NOTIFY_RECIPIENT)
+	    || (error_strategy == STRATEGY_NOTIFY_RECIPIENT)
+	    || (spam_strategy == STRATEGY_NOTIFY_RECIPIENT)
+	    || (unwanted_strategy == STRATEGY_NOTIFY_RECIPIENT))
+		desc.xxfi_flags |= SMFIF_CHGBODY;
 
 	desc.xxfi_connect = smtp_vilter_connect;	
 	desc.xxfi_helo = smtp_vilter_helo;
