@@ -1,4 +1,4 @@
-/*	$Id: smtp-vilter.c,v 1.169 2006/06/24 10:44:37 mbalmer Exp $	*/
+/*	$Id: smtp-vilter.c,v 1.171 2006/11/12 11:38:08 mbalmer Exp $	*/
 
 /*
  * Copyright (c) 2003, 2004, 2005, 2006 Marc Balmer <marc@msys.ch>
@@ -93,6 +93,7 @@ char	*tmpdir;
 int	 tmpfiles_gr;
 int	 tmpfiles_setgrp;
 char	*backend;
+char	*backend_path;
 char	*recipient_notification;
 char	*notify_only;
 int	 log_facility;
@@ -319,6 +320,7 @@ main(int argc, char *argv[])
 	chrootdir = NULL;
 	cfgfile = _PATH_CFGFILE;
 	backend = NULL;
+	backend_path = NULL;
 	virus_strategy = -1;
 	spam_strategy = -1;
 	unwanted_strategy = -1;
@@ -525,6 +527,8 @@ main(int argc, char *argv[])
 		tmpdir = strdup(_PATH_TMPDIR);
 	if (backend == NULL)
 		backend = strdup("clamd");
+	if (backend_path == NULL)
+		backend_path = strdup(_PATH_BACKEND);
 	if (virus_strategy == -1)
 		virus_strategy = STRATEGY_DISCARD;
 	if (spam_strategy == -1)
@@ -685,8 +689,8 @@ main(int argc, char *argv[])
 
 	/* Load the backends */
 	for (n = 0; n < nbe; n++) {
-		snprintf(libname, sizeof(libname), "libvilter-%s.so.%d",
-		    be[n].name, MAJOR);
+		snprintf(libname, sizeof(libname), "%s/vilter-%s.so",
+		    backend_path, be[n].name);
 
 		if (verbose)
 			warnx("loading backend %s from file %s", be[n].name,
