@@ -1,4 +1,4 @@
-/*	$Id: socket.c,v 1.18 2006/02/08 14:47:28 mbalmer Exp $	*/
+/*	$Id: socket.c,v 1.20 2006/06/05 15:32:56 mbalmer Exp $	*/
 
 /*
  * Copyright (c) 2003, 2004, 2005 Marc Balmer <marc@msys.ch>
@@ -45,9 +45,9 @@ to_recv(int s, void *buf, size_t len, int flags, struct timeval *timeout)
 ssize_t
 to_send(int s, const char *buf, size_t len, int flags, struct timeval *timeout)
 {
-	int	n;
-	int	sent;
-	int	retval;
+	ssize_t	n;
+	ssize_t	sent;
+	ssize_t	retval;
 	fd_set	wset;
 
 	n = sent = 0;	
@@ -56,7 +56,8 @@ to_send(int s, const char *buf, size_t len, int flags, struct timeval *timeout)
 	FD_SET(s, &wset);
 	while (sent < len) {
 		if ((n = select(s + 1, NULL, &wset, NULL, timeout)) > 0) {
-			if ((retval = send(s, buf + sent, len - sent, flags)) != -1)
+			if ((retval = send(s, buf + sent, len - sent, flags))
+			    != -1)
 				sent += retval;
 		} else
 			return n;
@@ -84,7 +85,8 @@ to_readc(SOCK *sock, char *c, struct timeval *to)
 {
 	if (sock->size <= 0) {
 		again:
-		if ((sock->size = to_recv(sock->sock, sock->buf, SOCK_BUFSIZE, 0, to)) < 0) {
+		if ((sock->size = to_recv(sock->sock, sock->buf, SOCK_BUFSIZE,
+		    0, to)) < 0) {
 			if (errno == EINTR)
 				goto again;
 			return -1;
